=== modified file 'lib/lp/code/mail/codereviewcomment.py'
--- lib/lp/code/mail/codereviewcomment.py	2010-03-18 22:10:42 +0000
+++ lib/lp/code/mail/codereviewcomment.py	2010-03-18 22:41:03 +0000
@@ -11,8 +11,7 @@
 
 from lp.code.enums import CodeReviewNotificationLevel
 from lp.code.mail.branchmergeproposal import BMPMailer
-from lp.services.mail import append_footer
-from lp.services.mail.sendmail import format_address
+from lp.services.mail.sendmail import append_footer, format_address
 
 
 def send(comment, event):

=== modified file 'lib/lp/services/mail/__init__.py'
--- lib/lp/services/mail/__init__.py	2010-03-18 22:04:52 +0000
+++ lib/lp/services/mail/__init__.py	2010-03-18 22:41:03 +0000
@@ -2,72 +2,3 @@
 # GNU Affero General Public License version 3 (see the file LICENSE).
 
 """Classes and utilities for Launchpad to send and receive email."""
-
-from zope.security.proxy import isinstance as zope_isinstance
-from lazr.enum import BaseItem
-
-
-def value_string(item):
-    """Return a unicode string representing an SQLObject value."""
-    if item is None:
-        return '(not set)'
-    elif zope_isinstance(item, BaseItem):
-        return item.title
-    else:
-        return unicode(item)
-
-
-def text_delta(instance_delta, delta_names, state_names, interface):
-    """Return a textual delta for a Delta object.
-
-    A list of strings is returned.
-
-    Only modified members of the delta will be shown.
-
-    :param instance_delta: The delta to generate a textual representation of.
-    :param delta_names: The names of all members to show changes to.
-    :param state_names: The names of all members to show only the new state
-        of.
-    :param interface: The Zope interface that the input delta compared.
-    """
-    output = []
-    indent = ' ' * 4
-
-    # Fields for which we have old and new values.
-    for field_name in delta_names:
-        delta = getattr(instance_delta, field_name, None)
-        if delta is None:
-            continue
-        title = interface[field_name].title
-        old_item = value_string(delta['old'])
-        new_item = value_string(delta['new'])
-        output.append("%s%s: %s => %s" % (indent, title, old_item, new_item))
-    for field_name in state_names:
-        delta = getattr(instance_delta, field_name, None)
-        if delta is None:
-            continue
-        title = interface[field_name].title
-        if output:
-            output.append('')
-        output.append('%s changed to:\n\n%s' % (title, delta))
-    return '\n'.join(output)
-
-
-def append_footer(main, footer):
-    """Append a footer to an email, following signature conventions.
-
-    If there is no footer, do nothing.
-    If there is already a signature, append an additional footer.
-    If there is no existing signature, append '-- \n' and a footer.
-
-    :param main: The main content, which may have a signature.
-    :param footer: An additional footer to append.
-    :return: a new version of main that includes the footer.
-    """
-    if footer == '':
-        footer_separator = ''
-    elif '\n-- \n' in main:
-        footer_separator = '\n'
-    else:
-        footer_separator = '\n-- \n'
-    return ''.join((main, footer_separator, footer))

=== modified file 'lib/lp/services/mail/basemailer.py'
--- lib/lp/services/mail/basemailer.py	2010-03-18 22:04:52 +0000
+++ lib/lp/services/mail/basemailer.py	2010-03-18 22:41:03 +0000
@@ -12,10 +12,10 @@
 
 from canonical.launchpad.helpers import get_email_template
 
-from lp.services.mail import text_delta
 from lp.services.mail.notificationrecipientset import (
     NotificationRecipientSet)
 from lp.services.mail.sendmail import format_address, MailController
+from lp.services.utils import text_delta
 
 
 class BaseMailer:

=== modified file 'lib/lp/services/mail/sendmail.py'
--- lib/lp/services/mail/sendmail.py	2010-02-12 21:40:26 +0000
+++ lib/lp/services/mail/sendmail.py	2010-03-18 22:41:03 +0000
@@ -15,6 +15,7 @@
 """
 
 __all__ = [
+    'append_footer',
     'format_address',
     'get_msgid',
     'MailController',
@@ -91,6 +92,26 @@
             "Address contains carriage returns: %r" % (addr,))
 
 
+def append_footer(main, footer):
+    """Append a footer to an email, following signature conventions.
+
+    If there is no footer, do nothing.
+    If there is already a signature, append an additional footer.
+    If there is no existing signature, append '-- \n' and a footer.
+
+    :param main: The main content, which may have a signature.
+    :param footer: An additional footer to append.
+    :return: a new version of main that includes the footer.
+    """
+    if footer == '':
+        footer_separator = ''
+    elif '\n-- \n' in main:
+        footer_separator = '\n'
+    else:
+        footer_separator = '\n-- \n'
+    return ''.join((main, footer_separator, footer))
+
+
 def format_address(name, address):
     r"""Formats a name and address to be used as an email header.
 

=== modified file 'lib/lp/services/utils.py'
--- lib/lp/services/utils.py	2009-10-19 05:40:52 +0000
+++ lib/lp/services/utils.py	2010-03-18 22:41:03 +0000
@@ -7,8 +7,13 @@
 __metaclass__ = type
 __all__ = [
     'iter_split',
+    'text_delta',
+    'value_string',
     ]
 
+from zope.security.proxy import isinstance as zope_isinstance
+from lazr.enum import BaseItem
+
 
 def iter_split(string, splitter):
     """Iterate over ways to split 'string' in two with 'splitter'.
@@ -27,3 +32,49 @@
     tokens = string.split(splitter)
     for i in reversed(range(1, len(tokens) + 1)):
         yield splitter.join(tokens[:i]), splitter.join(tokens[i:])
+
+
+def value_string(item):
+    """Return a unicode string representing an SQLObject value."""
+    if item is None:
+        return '(not set)'
+    elif zope_isinstance(item, BaseItem):
+        return item.title
+    else:
+        return unicode(item)
+
+
+def text_delta(instance_delta, delta_names, state_names, interface):
+    """Return a textual delta for a Delta object.
+
+    A list of strings is returned.
+
+    Only modified members of the delta will be shown.
+
+    :param instance_delta: The delta to generate a textual representation of.
+    :param delta_names: The names of all members to show changes to.
+    :param state_names: The names of all members to show only the new state
+        of.
+    :param interface: The Zope interface that the input delta compared.
+    """
+    output = []
+    indent = ' ' * 4
+
+    # Fields for which we have old and new values.
+    for field_name in delta_names:
+        delta = getattr(instance_delta, field_name, None)
+        if delta is None:
+            continue
+        title = interface[field_name].title
+        old_item = value_string(delta['old'])
+        new_item = value_string(delta['new'])
+        output.append("%s%s: %s => %s" % (indent, title, old_item, new_item))
+    for field_name in state_names:
+        delta = getattr(instance_delta, field_name, None)
+        if delta is None:
+            continue
+        title = interface[field_name].title
+        if output:
+            output.append('')
+        output.append('%s changed to:\n\n%s' % (title, delta))
+    return '\n'.join(output)

